# Changelog

<!--next-version-placeholder-->

## v1.1.0 (2022-05-21)
### Feature
* Init offer service ([`335ff72`](https://github.com/draganagrbic998/devops_offer_service/commit/335ff72ff54343dad2f3ee3e11a7aaaf2a45e7ce))
